# Analyzing the effect of gender in the three context experiments

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))  
# setwd('/home/allgoodguys/Documents/Studying/Lund_PhD/experiments/context/analysis')  

library(ggplot2)
library(brms)

df = read.csv('data/pooled.csv')  # table(df$id, df$exp)

df = droplevels(df[!is.na(df$response) & # in Exp 3 we get NA when participants skip a sound
                     !is.na(df$sex), ])  # exclude sex "other"  

# Same model as in "nonlin.R", but w/o sex "other"; short MCMC, just to see
# whether there is an effect of sex
mod_woSex = brm(bf(
  response ~ emGroup * cond * measure + (1|id) + (1|file) + (cond|sound),
  zoi ~ emGroup * cond * measure,
  coi ~ emGroup * cond * measure),
  data = df, family = 'zero_one_inflated_beta',
  cores = 4, chains = 4, warmup = 100, iter = 200,
  prior = c(set_prior('logistic(0, 1)', class = 'b', dpar = 'coi'),
            set_prior('logistic(0, 1)', class = 'b', dpar = 'zoi')))
# saveRDS(mod_woSex, 'mod/mod_nonlin_woSex.RDS')  # 
mod_woSex = readRDS('mod/mod_nonlin_woSex.RDS')
# summary(mod_woSex)
# pp_check(mod_woSex)

mod_withSex = brm(bf(
  response ~ emGroup * cond * measure * sex + (1|id) + (1|file) + (cond|sound),
  zoi ~ emGroup * cond * measure * sex,
  coi ~ emGroup * cond * measure * sex),
  data = df, family = 'zero_one_inflated_beta',
  cores = 4, chains = 4, warmup = 100, iter = 200,
  prior = c(set_prior('logistic(0, 1)', class = 'b', dpar = 'coi'),
            set_prior('logistic(0, 1)', class = 'b', dpar = 'zoi')))
# saveRDS(mod_withSex, 'mod/mod_nonlin_withSex.RDS')  # really slow, ~7 h / 200 iter
mod_withSex = readRDS('mod/mod_nonlin_withSex.RDS')
# summary(mod_withSex)
# pp_check(mod_withSex)

waic(mod_withSex, mod_woSex)  # -5.0, SE = 18.0 in favor of the model without sex
loo(mod_withSex, mod_woSex)   # -6.6, SE = 18.0: in terms of loo, we're again better off without sex  ;))
