# Analyzing the overall effect of context (ignoring nonlinearities) 
# in the three context experiments

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))  

library(ggplot2)
library(brms)

df = read.csv('data/pooled.csv')
df = droplevels(df[df$exp == 'exp3', ])

## pressing the "skip" button
aggregate(unsuitable ~ cond, df, mean)
aggregate(unsuitable ~ context + cond, df, mean)   # chaos >often deemed unsuitable in pos vs neg; no difference for subh or none


# mod_unsuit = brm(unsuitable ~ emGroup * cond * context + (1|subject) + (1|file) + (cond|sound), data = df, family = 'bernoulli', cores = 4, chains = 4, warmup = 500, iter = 4000)
# saveRDS(mod_unsuit, 'mod/resp_skip.RDS')
mod_unsuit = readRDS('mod/resp_skip.RDS')
# summary(mod_unsuit)
# pp_check(mod_unsuit)
# conditional_effects(mod_unsuit)

newdata = expand.grid(
  emGroup = levels(df$emGroup),
  cond = levels(df$cond),
  context = levels(df$context)
)
fit = fitted(mod_unsuit, newdata = newdata, re_formula = NA, robust = TRUE) * 100
colnames(fit) = c('fit', 'se', 'lwr', 'upr')
df_plot = cbind(newdata, fit)

for (i in 1:nrow(df_plot)) {
  df_plot$Manipulation[i] = switch(
    as.character(df_plot$cond[i]),
    'none' = 'None',
    'subh' = 'Subharmonics /\nsidebands',
    'chaos' = 'Chaos'
  )
  df_plot$emBlock[i] = switch(
    as.character(df_plot$emGroup[i]),
    'surprise' = 'Gasps\n(fright / surprise)',
    'pls-pain' = 'Moans\n(pain / pleasure)',
    'del-fear' = 'Screams\n(fear / delight)',
    'ach-frust' = 'Roars\n(frustration / achievement)'
  )
  df_plot$Context[i] = switch(
    'neg' = 'Negative context',
    'pos' = 'Positive context'
  )
}
df_plot$Manipulation = factor(df_plot$Manipulation, levels = c('None', 'Subharmonics /\nsidebands', 'Chaos'))
df_plot$emBlock = factor(df_plot$emBlock, levels = c())

ggplot(df_plot, aes(x = emGroup, y = fit, ymin = lwr, ymax = upr, color = cond, shape = cond)) +
  geom_errorbar(position = position_dodge(.5), width = 0) +
  geom_point(position = position_dodge(.5), size = 2) +
  xlab('') + ylab('Prob. of skipping as unsuitable') +
  coord_flip() +
  facet_grid(~context, shrink = TRUE) +
  theme_bw()
ggsave('pix/skip.png', width = 12, height = 10, units = 'cm', dpi = 300)


# contrasts
fit1 = fitted(mod_unsuit, newdata = newdata, re_formula = NA, summary = FALSE) * 100
contrasts1 = contrasts2 = expand.grid(
  context = levels(df$context),
  fit = NA, lwr = NA, upr = NA
)
for (i in 1:nrow(contrasts)) {
  idx = which(newdata$context == contrasts$context[i])
  idx_none = idx[which(newdata$cond[idx] == 'none')]
  idx_subh = idx[which(newdata$cond[idx] == 'subh')]
  idx_chaos = idx[which(newdata$cond[idx] == 'chaos')]
  subh_vs_none = rowMeans(fit1[, idx_subh] - fit1[, idx_none])  # average across 4 call types
  contrasts1[i, c('fit', 'lwr', 'upr')] = quantile(subh_vs_none, probs = c(.5, .025, .975))
  chaos_vs_none = fit1[, idx_chaos] - fit1[, idx_none]
  contrasts2[i, c('fit', 'lwr', 'upr')] = quantile(chaos_vs_none, probs = c(.5, .025, .975))
}
contrasts1$Manipulation = 'Subharmonics'
contrasts2$Manipulation = 'Chaos'
contrasts = rbind(contrasts1, contrasts2)
contrasts$ci = soundgen:::reportCI(contrasts[, c('fit', 'lwr', 'upr')], digits = 1)
contrasts


# same for all call types?
# mod_unsuit1 = brm(unsuitable ~ cond * context + (1|subject) + (1|file) + (cond|sound), data = df, family = 'bernoulli', cores = 4, chains = 4, warmup = 500, iter = 4000)
# saveRDS(mod_unsuit1, 'mod/resp_skip_noCallType.RDS')
mod_unsuit1 = readRDS('mod/resp_skip_noCallType.RDS')

waic(mod_unsuit, mod_unsuit1)  # mod_unsuit1 (w/o emGroup) is slightly better: -6.3, SE = 4.4
